ArtifactError

Enum ArtifactError 

pub enum ArtifactError {
    Io(Error),
    NotRegularFile,
    LimitExceeded {
        limit: u64,
    },
    DigestMismatch {
        expected: Sha256Digest,
        actual: ArtifactIdentity,
    },
    Allocation(TryReserveError),
}
A bounded read or digest verification failed.

Variants



Io(Error)

The reader or filesystem failed. No partial identity is returned.



NotRegularFile

The selected path is not a regular file.



LimitExceeded

A stream exceeded the caller’s byte allowance.

Fields

limit: u64

Maximum permitted bytes.



DigestMismatch

The complete bounded stream does not match the admitted digest.

Fields

expected: Sha256Digest

Caller-selected authority.

actual: ArtifactIdentity

Observed size and digest.



Allocation(TryReserveError)

Storage could not be allocated for a bounded file read.